bayespy.nodes.GaussianGamma
===========================

.. currentmodule:: bayespy.nodes

.. autoclass:: GaussianGamma

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGamma.__init__
      ~GaussianGamma.add_plate_axis
      ~GaussianGamma.broadcasting_multiplier
      ~GaussianGamma.delete
      ~GaussianGamma.get_gaussian_location
      ~GaussianGamma.get_gaussian_mean_and_variance
      ~GaussianGamma.get_gradient
      ~GaussianGamma.get_marginal_logpdf
      ~GaussianGamma.get_mask
      ~GaussianGamma.get_moments
      ~GaussianGamma.get_parameters
      ~GaussianGamma.get_riemannian_gradient
      ~GaussianGamma.get_shape
      ~GaussianGamma.has_plotter
      ~GaussianGamma.initialize_from_parameters
      ~GaussianGamma.initialize_from_prior
      ~GaussianGamma.initialize_from_random
      ~GaussianGamma.initialize_from_value
      ~GaussianGamma.load
      ~GaussianGamma.logpdf
      ~GaussianGamma.lower_bound_contribution
      ~GaussianGamma.lowerbound
      ~GaussianGamma.move_plates
      ~GaussianGamma.observe
      ~GaussianGamma.pdf
      ~GaussianGamma.plot
      ~GaussianGamma.plotmatrix
      ~GaussianGamma.random
      ~GaussianGamma.rotate
      ~GaussianGamma.save
      ~GaussianGamma.set_parameters
      ~GaussianGamma.set_plotter
      ~GaussianGamma.show
      ~GaussianGamma.translate
      ~GaussianGamma.unobserve
      ~GaussianGamma.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGamma.dims
      ~GaussianGamma.plates
      ~GaussianGamma.plates_multiplier
   
   